# Step-by-step tutorials

## Setup

For installing Sockeye follow the [installation instructions](../README.md#installation)
to manually install Sockeye and all dependencies. The tutorials below might have additional dependencies that
will be mentioned at the beginning of each tutorial.

## Tutorials

Below is the full list of tutorials we provide. We recommend going through them in order as they will gradually
introduce different concepts and parameters used for training and translation.

1. [Sequence copy task](seqcopy)
1. [WMT German to English news translation](wmt)
1. [Image captioning](image_captioning)
1. [Domain adaptation of NMT models](adapt)
1. [Decoding with lexical constraints](constraints)
1. [Process per core translation](process_per_core_translation)
